from distutils.core import setup
setup(name='pd_nester',version='1.1.0',py_modules=['pd_nester'],author='Priyam',author_email='priyam.great@gmail.com',url='http://www.gmail.com',description='Justlikethat',)
